
# q-expansion of newform 1100.6.b.h, downloaded from the LMFDB on 22 December 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1100
weight = 6
poly_data = [17431853564765025, 0, 10407170577870199, 0, 948941487871009, 0, 21366050398338, 0, 200757496958, 0, 904250402, 0, 2068257, 0, 2311, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[1063662967590841248526366425, 0, 5086578692010158985137468, 0, -171851639491069750400100, 0, -3518076226861367672334, 0, -22555576937906116100, 0, -63397597709479236, 0, -80815899405975, 0, -38214337648, 0], 3632019895277585054370000], [[15462025813730201835184425, 0, 1454558796732573930767468, 0, -171851639491069750400100, 0, -3518076226861367672334, 0, -22555576937906116100, 0, -63397597709479236, 0, -80815899405975, 0, -38214337648, 0], 1452807958111034021748000], [[22800820918132814111765711394706343925, 0, 22731371537394955185039727365743098093, 0, 516759483768333234839209528715108400, 0, 3849713957202232879285695176087166, 0, 13071776596206011238486257948150, 0, 22137438373272198927645249264, 0, 18075473021826914394590025, 0, 5598594399255967619977, 0], 207704589307616862022837805220420000], [[6449207275698628867695134462897348175, 0, 916534977810958574574885741851118688, 0, 17629413935941081250337613136179272, 0, 137407973995535124552780116079258, 0, 573554739721934216006459348336, 0, 1319986673586159201112727400, 0, 1537910131073998073706267, 0, 700447592029041441904, 0], 4154091786152337240456756104408400], [[-1618682801724719906906755551587332725, 0, -1488159530436579211256666853953575346, 0, 2343616458984868257370834511602800, 0, 344657783917411571913562582733898, 0, 2521334772568932536350986093500, 0, 7260394323201041761223428992, 0, 9282236635126177905272175, 0, 4386202337755133372206, 0], 20770458930761686202283780522042000], [[-58980963316994966297437814087162769600, 0, -2822762430400485876652816702274699591, 0, 142745900824302157161531529146325000, 0, 3004465095850362716415602655552608, 0, 18490861023838674859907889016350, 0, 49839964825379675006318635432, 0, 61475359148072229033836000, 0, 28383365780274504451301, 0], 69234863102538954007612601740140000], [[246285856278898240684588046318207262825, 0, 49890131589263353632555422860914067987, 0, 1484988697432135805712612290077892850, 0, 16220202710967214791593059616944044, 0, 78237714690051316662088908475100, 0, 184479763949344479803574233826, 0, 208777420683323823141617475, 0, 90733369094348338138393, 0], 103852294653808431011418902610210000], [[0, 3123040684301115711405227921475, 0, -8225227656234321753771533176979, 0, -182104542356867721229659693600, 0, -1618645871697974766920670798, 0, -6954482626764009407144650, 0, -15341711480019935474592, 0, -16683841055306802225, 0, -7073768543908631], 63937954747790167859237631420000], [[0, 60814914063489052147832403498525, 0, 8225227656234321753771533176979, 0, 182104542356867721229659693600, 0, 1618645871697974766920670798, 0, 6954482626764009407144650, 0, 15341711480019935474592, 0, 16683841055306802225, 0, 7073768543908631], 12787590949558033571847526284000], [[0, 54196822775882538395391130414659221766716025, 0, 10635394378861926940624390725044929045230509, 0, 288540289753475053819717915331373833940000, 0, 2995992980358459875296948418398686536358, 0, 14219243097215719772900441353156589350, 0, 33492715653764516709470910725221632, 0, 38087318334227182356359952526125, 0, 16665124986531776594357695001], 609404088035875130012787991102482697620000], [[0, -1243538444013985482562332838871252379878150925, 0, -43246958120764138044441830074241838145910188, 0, -958034287314521773421561216651750091168000, 0, -11031591935471313838470436193782479258006, 0, -56607249716226512786241550797791403200, 0, -139594315259463907289794171974911424, 0, -163108100203021248816705331559625, 0, -72576790737594887056493686132], 1828212264107625390038363973307448092860000], [[0, -650295644044093613631519608248274021047124175, 0, -9201093567425348978867066062814302127222393, 0, 481227195865732644692060487103934334083700, 0, 8931330631127779814855337769238901161634, 0, 52003051135371854940096037602962564150, 0, 135328041525636159704547231738414036, 0, 162834864989393391159709778475825, 0, 73804427922842191349373102223], 1828212264107625390038363973307448092860000], [[0, 221220157002895906170184875558117763082975850, 0, 67636206360105612337098127140090137457035671, 0, 1555693579380938812348459335186347495256900, 0, 14235718046286461029003746373325373796752, 0, 63885567165945150417450081547285224350, 0, 147898792456437215419296185548551108, 0, 168201014147403706587917304030150, 0, 74116201676020126723700891719], 1828212264107625390038363973307448092860000], [[0, 2007418692511768253076338148396775070367631200, 0, 242063012397756789279051999539021232119017267, 0, 5138322029485653075971674571876167661006700, 0, 44295585372602055226094356493916170691804, 0, 187554830846693817276904537934679377150, 0, 411789996696789335393645337053884716, 0, 447773026403885402889381047300700, 0, 190172068875366153249997057963], 1828212264107625390038363973307448092860000], [[0, -69671340223730600196868288645203823321732005, 0, -7475248035223041076614469012545133115935211, 0, -183144375856472250706073976124357657114932, 0, -1807988374831772146327446556444742184282, 0, -8377199421099677393364948011888609806, 0, -19501600401381180334726092866288148, 0, -22047043907357388155260979082357, 0, -9618381003509784353336193059], 73128490564305015601534558932297923714400]]

hecke_ring_character_values = [[551, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [177, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [101, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -2, 4, -1, 0, 0, 0, 0, 0], [-121, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -6, 26, -1, 0, 0, 0, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, -20, -3, -1, -1, 0, 1, 0, -1], [168, 0, 3, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 59, -19, -2, -1, -1, 0, 2, -1], [1472, -7, 5, 0, 0, 2, -3, -2, 0, 0, 0, 0, 0, 0, 0, 0], [435, -8, 15, 4, 3, 2, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 83, -185, -7, 6, -4, 1, -5, 0], [1990, -21, -35, 11, 0, -6, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 75, 34, -29, 4, 6, 1, 5, 4], [0, 0, 0, 0, 0, 0, 0, 0, 294, -171, -29, -2, -7, -12, 1, 7], [0, 0, 0, 0, 0, 0, 0, 0, 46, 642, -52, 3, 8, 6, 0, 1], [-224, 12, 145, 14, -19, 10, -7, -17, 0, 0, 0, 0, 0, 0, 0, 0], [-6805, -5, -27, 16, 25, -21, 22, -8, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 208, 2784, -120, -10, 23, 5, 7, 11], [-5577, 9, -107, -1, -3, 27, 5, -2, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 293, 113, -14, -45, -1, -10, 5, -12], [-9434, 95, 394, 22, -11, -5, 3, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 513, -18, -55, 36, 20, 19, -38, 16], [-13396, -15, 340, -10, -7, -16, -26, -20, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 964, 2122, 224, -46, 42, 33, 50, -50], [-5079, -6, -564, -27, -27, -46, -73, -38, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 540, -3690, 122, -52, 34, -40, 4, -5], [0, 0, 0, 0, 0, 0, 0, 0, 1406, 4968, -47, 57, 64, -75, -21, 5], [16016, -86, 468, -29, -11, -5, -144, 43, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 2728, 4133, 130, -13, -8, 27, -28, -37], [0, 0, 0, 0, 0, 0, 0, 0, 5875, 4368, 177, 33, -85, 5, -61, 94], [-20947, -164, -24, -149, -34, 81, 8, -96, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 3964, 1111, 452, 103, -29, -111, 19, -32], [-24898, -7, 1340, 63, 128, 0, 91, 59, 0, 0, 0, 0, 0, 0, 0, 0], [-88970, -405, 1379, -47, -73, -139, 95, -71, 0, 0, 0, 0, 0, 0, 0, 0], [-60271, 357, 767, 154, -111, -44, 68, -230, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1207, 12532, 755, -95, 18, 216, 73, 215], [0, 0, 0, 0, 0, 0, 0, 0, 6568, -20471, 88, -73, -175, 122, -20, -12], [0, 0, 0, 0, 0, 0, 0, 0, 5987, 30868, -1046, -93, -109, -55, 23, 252], [0, 0, 0, 0, 0, 0, 0, 0, 1437, 5854, -550, 177, 45, -243, -132, 23], [-136288, -68, -326, 234, -451, 48, 73, -77, 0, 0, 0, 0, 0, 0, 0, 0], [-94131, -637, -1524, 398, -209, -34, 126, 166, 0, 0, 0, 0, 0, 0, 0, 0], [-229227, -41, 1366, -339, 329, 101, -41, 300, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -12043, -27972, 365, -69, 293, 361, 76, 414], [0, 0, 0, 0, 0, 0, 0, 0, 130, 59079, -62, 103, 81, -54, 139, -251], [-84216, -263, -2952, -389, 348, -145, -465, 208, 0, 0, 0, 0, 0, 0, 0, 0], [-185894, 127, 3697, 552, 114, -418, 194, -250, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 7915, -53617, -476, -259, -557, -22, -116, 178], [0, 0, 0, 0, 0, 0, 0, 0, 1940, 62654, -510, 267, -196, -85, 23, -271], [-248212, 2654, -3428, -590, 512, -383, -552, -12, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -13547, -38849, 182, 69, -11, -318, 195, 830], [-536623, 1601, -3246, 311, 311, -86, 488, 12, 0, 0, 0, 0, 0, 0, 0, 0], [-281910, -1345, 1439, -486, -311, 26, 271, 285, 0, 0, 0, 0, 0, 0, 0, 0], [-464189, 2685, 2894, -575, -442, 73, -695, 437, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -25075, 50252, 4421, -432, -431, 252, -42, -21], [0, 0, 0, 0, 0, 0, 0, 0, -5640, 9602, 35, 452, 533, 465, 242, -809], [-420559, 1742, -7952, -152, 391, -241, -516, -252, 0, 0, 0, 0, 0, 0, 0, 0], [-396401, -1130, 6852, -419, 258, 693, 301, -45, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -38386, 117240, 2942, 155, 578, -60, -127, 1335], [-355112, -1636, 76, -176, 889, -179, 223, 543, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 8021, -41246, 2569, 299, 69, -673, -953, 480], [0, 0, 0, 0, 0, 0, 0, 0, -10197, -94370, 5297, -527, -1159, 263, -228, 166], [0, 0, 0, 0, 0, 0, 0, 0, -9096, 126920, 10302, -414, 199, -575, -326, -597], [-617813, -1673, 4132, 33, 714, -907, -734, 247, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -34484, -134334, 1814, -138, -592, -184, 62, 162], [0, 0, 0, 0, 0, 0, 0, 0, -5274, 128389, 2740, 48, -906, 11, 458, -246], [-285242, -6328, 8687, 594, -411, 208, 719, 245, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -21648, 252060, 5408, -696, -177, 681, -507, 41], [0, 0, 0, 0, 0, 0, 0, 0, 54392, 209342, -2151, -678, 67, 637, 799, 887], [-649234, 2391, -2899, -875, -1651, 516, -2220, 663, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1786, -73197, -3714, -146, 78, 418, 2192, -412], [-862729, -3854, 2710, 486, 1221, -312, 648, -1070, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 77684, 280123, 7853, 356, 130, -399, 986, -371], [0, 0, 0, 0, 0, 0, 0, 0, -7937, -159958, 14725, 218, 820, 50, 976, -2018], [-586062, 4381, -3918, -3053, 1532, -151, -656, 40, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 29610, -7492, -12269, 1333, -630, -1818, -3083, -546], [-821128, 1747, 1215, 1993, 1435, 621, -645, 735, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 26701, 208023, -4085, -1183, -2333, -2152, 298, -1286], [-1213623, 665, -10948, 4332, 8, -71, 958, -1296, 0, 0, 0, 0, 0, 0, 0, 0], [-715405, -6781, 279, -1549, -2399, -92, -334, 332, 0, 0, 0, 0, 0, 0, 0, 0], [-96911, -2146, 293, -2556, -206, -894, -3283, 2105, 0, 0, 0, 0, 0, 0, 0, 0], [-252959, 4213, -14426, 5310, 215, -198, 88, 346, 0, 0, 0, 0, 0, 0, 0, 0], [116357, -6474, 8748, 2553, -1090, 1165, -851, 2221, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 14131, -71817, 8177, 983, 526, -140, 219, 1831], [-437857, -1523, 10910, 164, -30, -77, -307, -3399, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 75763, -37536, -9771, -1507, 1030, 2880, -1309, 1945], [-640208, -500, 10454, 2546, -1705, 3255, -874, -878, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 84323, 126161, -11450, 1067, -1460, 1251, -838, 267], [-1120022, -3757, -4811, -5687, 420, 690, 322, -2186, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 89775, -174615, -10997, -2146, 912, 663, 1994, -1903], [0, 0, 0, 0, 0, 0, 0, 0, 82274, -56207, -4851, -2786, -3435, -310, 2205, 1551], [272241, -857, 9037, -4434, -2821, 1544, -2696, 3828, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 182987, 311625, -3749, 1594, -866, -2447, -760, -2677], [197393, -1066, 20265, -1744, 482, -229, -12, -754, 0, 0, 0, 0, 0, 0, 0, 0], [225849, -378, 19318, -70, 1802, -178, 2785, 733, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 109661, -206262, 797, -761, 2001, 3189, -2594, 2058], [89557, -3301, 38974, 2224, 2023, -1396, -892, 98, 0, 0, 0, 0, 0, 0, 0, 0], [-376116, 1378, 3519, -5939, -3624, -3478, -1283, -3319, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 236040, -144462, 13480, 1605, 1627, 2236, 1021, -4064], [-995245, -12123, -9043, -1676, -518, -2511, -1488, 461, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 256843, -62860, 36306, -1844, 3209, 3190, 686, -1087], [0, 0, 0, 0, 0, 0, 0, 0, 102089, 73764, -6616, 3743, 1518, -78, -1291, -1954], [0, 0, 0, 0, 0, 0, 0, 0, -26571, -281692, 7626, -1963, 1227, -379, 3628, -6384], [-1434199, -6807, 52133, 4420, 4139, -2129, 3728, -1644, 0, 0, 0, 0, 0, 0, 0, 0], [1143207, 11062, 44212, -15507, 858, 1987, -4086, 2366, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -240779, -19505, -19489, 2385, 4108, -2555, -539, 2721], [0, 0, 0, 0, 0, 0, 0, 0, 86137, -232016, 41264, 1670, -1256, -3948, -3052, -3492], [0, 0, 0, 0, 0, 0, 0, 0, -94632, 97446, 43054, -5529, 6893, 1305, 7152, 2072], [821285, -2682, -86017, -2738, 2169, 1796, 4874, -1480, 0, 0, 0, 0, 0, 0, 0, 0], [-1025708, 4518, -12106, 937, -4685, -1540, -1757, -3991, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -156732, 474774, -24562, 174, -1143, 1293, -1083, -13039], [0, 0, 0, 0, 0, 0, 0, 0, 54221, 496517, -2260, -3376, -217, -3342, -520, -8691], [0, 0, 0, 0, 0, 0, 0, 0, -93418, -358626, -25400, 2241, 1858, 2409, -1104, 3551], [1500209, 13742, -2229, -1606, 1448, -4770, -5799, 1035, 0, 0, 0, 0, 0, 0, 0, 0], [3729062, 18582, 66844, -1024, -527, -856, -5589, -2425, 0, 0, 0, 0, 0, 0, 0, 0], [-1283212, -19659, 46359, 2595, 6930, -2087, 14997, 1747, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -256676, -158344, -2966, -5316, 20, 7092, 1662, 504], [0, 0, 0, 0, 0, 0, 0, 0, -21389, -126959, -6814, 461, -2402, 5301, -4243, 3453], [0, 0, 0, 0, 0, 0, 0, 0, -82110, 509213, 32154, -280, -3845, 4206, -2965, 5097], [3733096, 3586, -13568, 10122, -2786, -3396, 7573, 1587, 0, 0, 0, 0, 0, 0, 0, 0], [2733095, -8366, 12791, 6275, 8050, 3726, -3055, -1227, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -168350, 391394, 15328, -255, -7443, 1387, -1400, -7890], [0, 0, 0, 0, 0, 0, 0, 0, 152100, -1205894, -23799, 2405, 5698, -4480, 4615, 1868], [0, 0, 0, 0, 0, 0, 0, 0, 66385, -72995, -34574, 1861, 2839, -100, -690, 10598], [3772619, 6111, 38379, -5175, 8811, -8951, -3326, 926, 0, 0, 0, 0, 0, 0, 0, 0], [2115708, 31756, -2168, 3216, -3733, -1884, -6466, 2375, 0, 0, 0, 0, 0, 0, 0, 0], [3632323, -8568, -168988, -7118, -7193, 1322, 3086, -1866, 0, 0, 0, 0, 0, 0, 0, 0], [4118894, 8653, -138528, 6283, -10268, -4615, 2162, -12374, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -223451, -1365994, -26151, -4223, -832, -5060, -2269, 12830], [0, 0, 0, 0, 0, 0, 0, 0, 142555, 766882, -17074, -6143, -1780, 3426, -347, 9702], [5142768, 32845, -143248, 2567, 5722, -2412, -2444, 3002, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 110345, -531928, -14890, -1969, -11556, -5608, -5033, 6409], [3358524, 31167, 15564, 10539, -3958, 4411, -861, -54, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 57663, -1344841, -36605, -7868, -4067, 3338, 6954, 8137], [3588293, -9616, 106034, 11520, -5605, 2502, -3784, -8538, 0, 0, 0, 0, 0, 0, 0, 0], [-1208370, -2633, -53861, -8211, 1738, 16556, 5476, 3590, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 484489, 1294624, 12125, -2930, -4047, -6493, 654, -9701], [0, 0, 0, 0, 0, 0, 0, 0, 197362, -1079028, 11081, -2334, -2584, 6994, -4853, -16090], [0, 0, 0, 0, 0, 0, 0, 0, -43114, -2533091, 65188, 6026, -16234, -3205, -12272, 6412], [7128009, 6900, 34796, 286, -2277, -18170, -12982, -3800, 0, 0, 0, 0, 0, 0, 0, 0], [5318959, -33532, -2102, -11831, -11338, -1051, 14483, -5427, 0, 0, 0, 0, 0, 0, 0, 0], [-1133781, 13817, 80395, -4397, 11143, 3389, 14059, 13660, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -224573, -996068, 23331, -6499, 10403, 5587, 14628, -8030], [0, 0, 0, 0, 0, 0, 0, 0, -31751, -894820, 43455, -10722, -3173, -2596, 13316, 4487], [-77673, 62078, -51098, 2536, 9309, 2767, 12744, 6730, 0, 0, 0, 0, 0, 0, 0, 0], [3070224, 40039, 96155, 653, 3232, 11379, -724, 372, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 101758, 1445085, -12695, -7085, 15176, 13183, 2780, 1731], [0, 0, 0, 0, 0, 0, 0, 0, 10054, -1083688, -12584, -4719, 9686, -8714, 4417, -16151], [12934083, -32089, 64019, 16005, 7388, -551, -2343, -4327, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -681020, -448227, -28216, -6189, -9047, -1072, 7076, -6329], [0, 0, 0, 0, 0, 0, 0, 0, 786519, -588148, -43084, 732, 5948, 334, -12482, 493], [319498, 48104, 57456, -5506, -8771, -9611, -9808, 488, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 751058, -1654243, -5333, -17896, 495, -4848, 14951, -8219], [0, 0, 0, 0, 0, 0, 0, 0, 254431, -515818, 27326, -7433, -2799, 7491, 6679, -14926], [0, 0, 0, 0, 0, 0, 0, 0, -543812, -774996, -17140, 6338, -2187, -1873, -5363, 5529], [10974309, -78700, 20666, 1110, 9505, -776, -1162, 9084, 0, 0, 0, 0, 0, 0, 0, 0], [14719805, -10061, 62667, 5923, 1418, 11977, -17809, 12997, 0, 0, 0, 0, 0, 0, 0, 0], [-876741, 34686, -193916, 4622, -538, 80, 7724, -10888, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -453803, 390192, -419, 18993, 4500, 7570, -23225, 777], [-2531090, 27025, 27887, -17257, 6274, -4370, -12044, -7548, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 798300, -1420205, 97433, -2368, 14210, 12965, 8548, 17760], [0, 0, 0, 0, 0, 0, 0, 0, 286809, 2518122, 42249, -6441, 24387, 6219, 5190, -14964], [0, 0, 0, 0, 0, 0, 0, 0, -92742, 364488, -118702, 1804, 592, 5110, 6551, 17950], [7395821, 38726, -138566, -12494, 1892, 3598, -16001, -4373, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 983705, -1750957, 28167, 18996, -10679, -6710, -15308, -1081], [0, 0, 0, 0, 0, 0, 0, 0, -91807, 810804, -98120, -16756, -14536, 17362, -1350, -1437], [16717444, 14416, -41327, 894, -24828, 3536, -5668, -11416, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 938492, -785041, -29683, -5135, 10474, -2105, -10684, 18531], [-1147784, -32694, 417734, 11722, 5747, 2595, 14663, 15029, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 795674, 4725970, -88548, -882, 3709, -13587, -4881, -17699], [-1107913, -6750, 395338, 17687, -23268, 1769, 4662, -12662, 0, 0, 0, 0, 0, 0, 0, 0], [-2680450, -18136, 190361, 1713, -2801, 13419, 7303, 3619, 0, 0, 0, 0, 0, 0, 0, 0], [6804716, -44693, -58212, 33850, -18415, 11971, 22707, -8191, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 653428, 1930549, -248825, 8282, -9412, -6523, -21587, -2940], [13574396, 7265, -380394, 35999, 18801, -5107, 10390, -8243, 0, 0, 0, 0, 0, 0, 0, 0], [2744779, 46463, -283154, -11762, -8316, 5903, -37284, 16622, 0, 0, 0, 0, 0, 0, 0, 0], [8015674, 73943, -144028, -33798, -8049, -3857, 9170, 13514, 0, 0, 0, 0, 0, 0, 0, 0], [-7096173, 6317, 281772, -15412, 13953, -19315, -5406, 7104, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 339046, -3314234, -149560, 1606, -7987, 855, -8561, 4119], [-14792911, -891, -315381, 12471, -13949, 6193, 32023, 318, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -567871, 1067220, 89646, -15516, -5549, -21573, 9177, -20786], [-978955, 7691, 42300, 28397, -7543, 14414, -8292, -18688, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -540718, 932997, -185820, -11271, 11893, -16100, 16297, 21998], [0, 0, 0, 0, 0, 0, 0, 0, 1513168, 939054, -114096, 996, 9890, -1406, -6410, -36798], [0, 0, 0, 0, 0, 0, 0, 0, -375983, -1534323, 7616, 19863, 11685, 16978, -16100, -10694], [-16177842, -125003, -39270, 5980, 39796, -7577, 32174, -10236, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1378089, -165256, -176328, -7300, 3561, 4365, 8423, 7558], [0, 0, 0, 0, 0, 0, 0, 0, 797250, -2716447, 102520, 9377, 3702, 19127, -21983, -28211], [-12238295, 81120, 154402, -6616, 3256, -3139, -29487, -5683, 0, 0, 0, 0, 0, 0, 0, 0], [-3749827, -9873, -82339, 21001, 43748, -27263, -9751, -8847, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 2319, 811115, -193865, -12918, -18169, 9295, 18238, -21099], [0, 0, 0, 0, 0, 0, 0, 0, 1818563, -4229550, -51515, -18150, -4826, -14517, 18459, 29798], [-585837, 13839, 301864, -42991, -10243, 9823, 12848, -19016, 0, 0, 0, 0, 0, 0, 0, 0], [-9394260, 1037, 257185, 58441, -29075, -11678, -1425, -17461, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -278031, 6916818, -111640, 2014, -31255, -7874, -29878, -37233], [0, 0, 0, 0, 0, 0, 0, 0, -1247542, 3390687, 275310, -2882, -12491, 15047, -4119, -44101], [-15405423, 27686, 109044, -24862, -15387, -566, -62010, 23432, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1552633, 284143, -65083, 17566, 13848, 26905, 10583, 72654], [0, 0, 0, 0, 0, 0, 0, 0, 747024, 3929453, -128517, -4620, -10795, -3200, -18182, -5005], [0, 0, 0, 0, 0, 0, 0, 0, -2013721, -3464912, 103995, -257, 30000, 12446, -1854, 30663], [-12747184, -64464, 223342, 6143, -28034, 44312, -16735, -17288, 0, 0, 0, 0, 0, 0, 0, 0], [-3529184, 99609, 229188, 21999, 29702, 13250, 32156, 26844, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1993454, 1197337, 183116, -11304, -9528, -21255, 6786, 12438], [-9117383, -110356, -29932, 2685, -6401, 30757, 13730, 20340, 0, 0, 0, 0, 0, 0, 0, 0], [-1444173, -16940, -545868, 7276, 33799, -9936, 17536, 24262, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 345986, -1246844, 125100, -12729, 13694, 10702, -1022, -52823], [-6041901, 38157, 82619, 25831, -16458, -23215, 49157, -1201, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1147964, -611594, -264955, -13265, 6756, -21515, 4493, -32945], [-33304381, -76530, -586428, 42414, 7121, 11598, 71760, 4454, 0, 0, 0, 0, 0, 0, 0, 0], [20252100, -63586, 64832, 26316, 38481, -22390, -6895, -21153, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 279782, 3976432, -87294, -11351, 20152, -16202, 62573, 19297], [-17516840, -34147, 238960, -40304, -25416, 8821, -736, -38952, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -3983708, -6466969, 111712, 507, 23159, 7896, -10050, -6480], [0, 0, 0, 0, 0, 0, 0, 0, 1488631, 5167148, 100451, 23623, -21641, -8531, 7190, 44504], [-27438251, 144301, -209747, -12378, 16615, 14192, 28512, 10480, 0, 0, 0, 0, 0, 0, 0, 0], [-1358695, -52527, 86046, -67344, 30556, 9067, -37500, 15986, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 70434, 8884960, 24848, 1040, 14782, 27734, 18670, -20444], [-33384406, 10168, -259660, -49255, 23900, 10007, -30484, 34200, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 56517, 3562775, 59340, 20905, -32385, -7738, -32976, 33559], [0, 0, 0, 0, 0, 0, 0, 0, -940010, 3861802, 48454, 4473, 34632, -14258, -19100, 23601], [-7401956, -41400, 154520, -32933, -2638, -9609, 14422, -5300, 0, 0, 0, 0, 0, 0, 0, 0], [-19124278, 78890, -695818, -33099, 43475, -1077, 45367, 21125, 0, 0, 0, 0, 0, 0, 0, 0], [-10158727, -81787, -428338, 84810, -28954, -65137, -46466, -39092, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1735990, -4006862, 116977, 40637, 18442, -16836, -54469, 3393], [0, 0, 0, 0, 0, 0, 0, 0, 3369243, 6617192, -103450, -74839, 2547, 29401, 32769, -13934], [-10551629, -143103, -141061, -42851, 46518, -52440, 26698, 30803, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -22504, 3794466, -125614, -17361, -497, -20789, -43727, 8848], [-28154737, 248113, -328211, -10407, 25149, -32947, -2545, -38890, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 604555, 2549188, 196053, 11701, 4874, 45468, -28535, -72323], [-23362045, -115161, -144005, 77477, -5966, 20981, 50438, -15122, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -619978, -2148932, 61860, -29953, -30299, 593, 29695, -70898], [-7623259, -65050, 456433, 13840, 33172, 45435, 6894, 40732, 0, 0, 0, 0, 0, 0, 0, 0], [-1073403, -112589, -9375, -62546, 18281, 53670, 8542, 27884, 0, 0, 0, 0, 0, 0, 0, 0], [-38137771, 96406, -336840, 13018, 1082, 30481, -43005, -895, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1570511, -8421300, -124792, -16654, -7687, 30865, -42633, -52487], [0, 0, 0, 0, 0, 0, 0, 0, -3150666, 8208368, 189119, -5970, -6801, -20189, 34510, 52617], [-15056680, 71391, -173846, 19694, 25011, -32145, 64782, -45346, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -201163, 6585361, -192301, 33396, 8877, 19630, -36866, -66154], [-6715715, 48135, 633526, 59957, 13604, 28103, -23781, -24279, 0, 0, 0, 0, 0, 0, 0, 0], [8842612, 154827, 543255, 98577, -47412, -3049, 42540, -28648, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 825036, -6240941, -52547, 7894, -30997, -47246, -10801, 41723], [-9219853, -329685, -229091, 14861, 6806, -51441, 19773, -32441, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1077917, -8159808, 91580, -20868, 5507, -39017, 34459, -69402], [-30135441, -56807, 52272, -23576, 22721, 14493, -2902, 26730, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -798150, -2380084, -50124, -8048, -42255, -45217, 53649, 8893], [5002426, -61534, -160057, -29646, -74377, 21317, -76083, 62463, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -551516, 3700045, 53727, -3166, -51811, -51156, 19379, 49614], [-47250322, 203283, 193731, 64509, -22872, -6887, 17334, -10982, 0, 0, 0, 0, 0, 0, 0, 0], [15485890, -56523, 1075467, -37353, 58743, -24063, 36816, 62790, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 274538, -5189860, -349618, 58030, 17951, 32383, 1121, -19135], [0, 0, 0, 0, 0, 0, 0, 0, -120114, 14211902, -99729, -33691, -35241, 12315, -17494, -79361], [7876591, -180602, -227796, -21650, 32910, 29575, 11287, 6745, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1083764, 3087496, -178791, -28613, 28242, -1530, -27119, 60516], [-21198698, 40572, 711700, -68542, 4323, 5164, 7044, -36138, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 2104662, 4097405, 140166, -9203, 2853, 27092, 52311, 14923], [-16320194, -168794, 331881, 34837, 100072, -51444, 10925, -43039, 0, 0, 0, 0, 0, 0, 0, 0], [30202019, 54234, -382261, 53899, 21378, -83618, 8537, 20965, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 3872116, 10325154, -293891, 37106, -3748, -9468, -26323, 34930], [0, 0, 0, 0, 0, 0, 0, 0, -3020981, 4167586, -130917, -3924, 27870, -23364, 3771, 74086], [0, 0, 0, 0, 0, 0, 0, 0, 733724, 9761654, 213206, 28976, 12022, 49564, -40416, 44648], [0, 0, 0, 0, 0, 0, 0, 0, -3183581, -13839744, 266601, -10851, 43448, 17322, 10587, -57793], [0, 0, 0, 0, 0, 0, 0, 0, 2916399, -5169034, -578321, 1016, -1287, -66828, 14540, 26879], [-2198590, 183640, 774620, 24518, -64318, -35097, -34489, -60680, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1674552, -3886287, 287132, -13838, 61597, 12326, 108108, -1966], [0, 0, 0, 0, 0, 0, 0, 0, 1214405, 441103, 5251, -88911, 36587, 30923, 69956, -45150], [52349847, -66443, 43449, 112519, -107124, 24995, 15195, -18623, 0, 0, 0, 0, 0, 0, 0, 0], [27445908, 78462, 6387, 53559, 34529, -29778, -4133, -37989, 0, 0, 0, 0, 0, 0, 0, 0], [-26935330, 223447, -44545, 60551, 118446, -25932, 34037, -16879, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 5298640, -15289186, -65787, 331, -16771, 62042, -55374, 59940], [0, 0, 0, 0, 0, 0, 0, 0, 3295855, 6798282, 152493, 11178, -3706, 18412, 75490, -49992], [-17520731, -65240, -202090, 25478, 95659, 27668, 136524, 58026, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 3655792, 9469727, 200555, -36696, 6090, -42053, -1640, -103106], [0, 0, 0, 0, 0, 0, 0, 0, -342502, 82718, 408208, -8253, -86126, 14479, 18100, -38127], [27691960, -239397, -224977, 83740, -72614, 20860, 8860, -5696, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1524746, -5350807, -160405, -41063, -15300, -23253, -78734, -69951], [0, 0, 0, 0, 0, 0, 0, 0, 2119039, -11217923, 308335, 94996, 38227, -35768, 7373, 51592], [0, 0, 0, 0, 0, 0, 0, 0, -794655, -4258942, -330019, 74511, 107727, 47581, 60628, 44712], [2960075, 189098, 558364, -188843, 16857, -2095, -77856, 44972, 0, 0, 0, 0, 0, 0, 0, 0], [50058350, 63031, -1069219, 56120, -77122, -7633, -31248, -69056, 0, 0, 0, 0, 0, 0, 0, 0], [23867088, 185086, -454540, 42131, 42373, -62499, -115105, -29229, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 5374876, 3148642, 131334, -8992, -37224, -75054, -59125, -19204], [26800830, 160736, 50752, -148112, -102211, 99828, -74170, 85231, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 781974, 8371210, -68595, -29792, -23288, -4282, -73116, -3666], [20563502, 11850, -36116, 38450, -95748, 118009, 4269, -54318, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 3557095, -207734, 278436, 34258, 77288, 4119, 89407, 39130], [20887775, -81732, 219050, 70672, 38334, -62834, 94078, -112569, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 373408, -52193, -305600, 13949, 26411, -51349, -14813, -64014], [0, 0, 0, 0, 0, 0, 0, 0, -1529783, 5347671, 211739, -24126, 75014, -13869, -31029, -145547], [2589611, 58201, -600569, -88791, -32824, 111513, 4224, -21183, 0, 0, 0, 0, 0, 0, 0, 0], [9154561, 256825, -49631, 125844, -13512, 12140, -100193, 26743, 0, 0, 0, 0, 0, 0, 0, 0], [-33199118, 172657, -380132, -31062, 41314, 92899, 80516, 5966, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 3646867, -27083001, -2516, -19539, -64140, 23931, -26241, -137761], [0, 0, 0, 0, 0, 0, 0, 0, -2852865, -640752, 830389, 34553, 47730, -100412, -36075, 62181], [39176412, 126999, 85937, -6425, 62661, -104617, 44946, 87372, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1692955, -3732398, 136720, 53917, -39304, -176374, -24909, 100012], [-49996078, 16419, -1023253, 131284, 10575, 4613, -82720, -22669, 0, 0, 0, 0, 0, 0, 0, 0], [140627752, -186846, -27549, -173898, 50584, -12854, -53293, 88, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1392892, 16976675, -208758, -47623, 40363, 47824, 55833, 64920], [-6536354, -578741, 32964, -70964, 53053, 60355, -22038, 56242, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -4844246, 7111418, -340613, -54321, 17860, -46505, -17297, 62495], [0, 0, 0, 0, 0, 0, 0, 0, -6243252, -13373344, -83522, 74989, 83192, 83824, -37603, -55489], [0, 0, 0, 0, 0, 0, 0, 0, -1048856, -31061290, -319831, -79059, -32401, 80243, -12424, -79881], [10609560, 30440, -194607, -85336, 137621, 11683, 242429, 84831, 0, 0, 0, 0, 0, 0, 0, 0]]
